This function calls a static method on a .NET type (class).
Usage
.cstatic(classname, methodname, ...)
Arguments
classname
The name of the .NET based class to be created. Can either be a fully qualified name like "com.stg.models.DickeyFuller" or "DickeyFuller" if the classname is unique in the VM.
methodname
name of the static method to be called on type
...
a sequence of arguments to the method. The arguments can either be fundamental types, vectors, matrices, or other objects. Fuzzy matching will be applied, allowing imperfectly matched argument types to be converted, as may be needed given R's more basic type system.